import { select, 
         csv,
         scaleLinear,
         max,
         scaleBand,
         axisLeft,
         axisBottom,
       	 descending,
       	 sort,
         format } from 'd3';

const plt = select('svg'); // Connection to DOM

const width = +plt.attr('width');
const height = +plt.attr('height');

const render = data => {
  const xValue = d => d.pages;
  const yValue = d => d.book;
  const margin = { top: 70, right: 30, bottom: 60, left: 250 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.1);
  
  const g = plt.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxisTickFormat = number => 
  	format('.2r')(number)
  		.replace('k', 'K')
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight)
  
  g.append('g')
    .call(axisLeft(yScale))
  	.selectAll('.domain, .tick line')
  	.remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(${0}, ${innerHeight})`);

  xAxisG
    .select('.domain')
  	.remove();
  
   xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 50)
  	.attr('x', innerWidth / 2)
  	.attr('fill', 'black')
  	.text('Pages');
  
	g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		.attr('height', yScale.bandwidth());
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('y', -10)
  	.text('My favourite books!');
};

csv('data.csv').then(data => {
  data.
    forEach(d => {
      d.pages = +d.pages;
    });
  
  data.sort(function(x, y){
   return descending(x.pages, y.pages);
})
  console.log(data);
	render(data);
});
